# FragmentColor API Documentation

The md files in this folder are used by `lsp_doc` macro
to generate all Doc Strings in the library.

The folder structure mimics our public API and modules inside `/src`.

Centralising all documentation here ensures we have the same Doc Strings
for the core Rust structs and all bindings.

The same documents are also used to create the Website,
ensuring consistency between the API documentation and the user-facing content.
